@@ -2,9 +2,9 @@ static char *fallback_resources[] = {
     "*connectLineColor: blue",
     "*connectLineTime: 1200",
     "*aboutString: Shisen-sho for X11 ver " XSHISEN_VERSION " \\n\\n"
-    " Shisen-sho for X11    by Masaoki Kobayashi (masaoki@techfirm.co.jp)\\n"
-    "   Shisen-sho for Win  by Shinji Ono (HFC02755@nifty.ne.jp)\\n"
-    "   Picture             by Takayuki Akiyama",
+    " Shisen-sho for X11    by Masaoki Kobayashi <masaoki@techfirm.co.jp>\\n"
+    "   Shisen-sho for Win  by Shinji Ono <ono@urban.ne.jp>\\n"
+    "   Picture             by Takayuki Akiyama <taco3@ybb.ne.jp>",
     "*tedumari: No pieces available to get",
     "*timeFormat: Your time is %2.2d:%2.2d.",
     "*displayFormat1: Pieces left: ",
@@ -45,6 +45,8 @@ static char *fallback_resources[] = {
     "*mb.button_1.mnemonic: O",
     "*mb.button_2.labelString: Configuration",
     "*mb.button_2.mnemonic: C",
+    "*mb.button_3.labelString: Picture",
+    "*mb.button_3.mnemonic: P",
     "*pd0.button_0.labelString: Start",
     "*pd0.button_0.mnemonic: D",
     "*pd0.button_0.accelerator: Ctrl<Key>D",
@@ -84,8 +86,10 @@ static char *fallback_resources[] = {
     "*pd2.button_2.labelString: Huge    (36x16)",
     "*pd2.button_3.labelString: Click Trial",
     "*pd2.button_4.labelString: Gravity",
+    "*pd3.button_0.labelString: Picture#1",
+    "*pd3.button_1.labelString: Picture#2",
     "*drawing.translations: #replace <Btn1Down>: PickupPiece()\\n"
-    "  <Btn2Down>(2): menu(0,0)\\n",
+    "  <Btn2Down>(2): menu(0,0)\\n"
     "  <Btn3Down>: CancelPiece()",
 #else /* USE_MOTIF */
     "*form.sform.label0.foreground: #f0f0f0",
@@ -108,6 +112,7 @@ static char *fallback_resources[] = {
     "*mb.pd0.label: Game",
     "*mb.pd1.label: Operation",
     "*mb.pd2.label: Configuration",
+    "*mb.pd3.label: Picture",
     "*pd0*button_0.label: Start          Ctrl-D",
     "*pd0*button_1.label: Restart        Ctrl-R",
     "*pd0*button_2.label: Pause          ESC",
@@ -122,8 +127,10 @@ static char *fallback_resources[] = {
     "*pd2*button_2.label: Huge    (36x16)",
     "*pd2*button_3.label: Click Trial",
     "*pd2*button_4.label: Gravity",
+    "*pd3*button_0.label: Picture#1",
+    "*pd3*button_1.label: Picture#2",
     "*sform*translations: #replace <Btn1Down>: PickupPiece()\\n"
-    "  <Btn2Down>(2): menu(0,0)\\n",
+    "  <Btn2Down>(2): menu(0,0)\\n"
     "  <Btn3Down>: CancelPiece()\\n"
     "  Ctrl<Key>D: menu(0,0)\\n"
     "  Ctrl<Key>R: menu(0,1)\\n"
